Class: Infopark::Crm::Core::Enumerator

Inherits:
Enumerator
  • Object
show all
Defined in:
lib/crm_connector/core/enumerator.rb

Overview

Transparent wrapper for the web services continuation ability

Instance Method Summary collapse

Instance Method Details

#sizeInteger

The total count given by the last search response, if available. If not available this method is undefined.



# File 'lib/crm_connector/core/enumerator.rb', line 28


#within_limitArray

The results of the last response as an array. The size of the array is less than or equal to the limit parameter value.



24
25
26
# File 'lib/crm_connector/core/enumerator.rb', line 24

def within_limit
  @collection.to_a
end